@@ -8,7 +8,7 @@ from .Errors import ConnectionFailedError, InvalidAuthError, InvalidDataReceived
 class Client:
     """Base remote console client"""
 
-    def __init__(self, host: str, auth: str) -> None:  # host is a string like '0.0.0.0' or '0.0.0.0:25575', auth is a string (rcon.password in server.properties)
+    def __init__(self, host: str, auth: str, timeout: int = 5) -> None:  # host is a string like '0.0.0.0' or '0.0.0.0:25575', auth is a string (rcon.password in server.properties)
         split = host.split(':')
 
         self.host = split[0]
@@ -16,6 +16,8 @@ class Client:
 
         self.auth = auth
 
+        self.timeout = timeout
+
         self._reader = None
         self._writer = None
 
@@ -25,10 +27,13 @@ class Client:
 
     async def _setup(self) -> None:
         try:
-            self._reader, self._writer = await asyncio.open_connection(self.host, self.port)
+            self._reader, self._writer = await asyncio.wait_for(asyncio.open_connection(self.host, self.port), timeout=self.timeout)
         except TimeoutError:
             self._closed = True
             raise ConnectionFailedError('A timeout occurred while attempting to connect to the server')
+        except asyncio.TimeoutError:
+            self._closed = True
+            raise ConnectionFailedError('A timeout occurred while attempting to connect to the server')
         except ConnectionRefusedError:
             self._closed = True
             raise ConnectionFailedError('The connection was refused by the server')
